Imports MSXML2

Public Class OrderContentHandler
    Implements IVBSAXContentHandler

    ' Raise this event when we finish processing an Order.
    Public Event OrderTotaled(ByVal order_total As Double)

    ' The current Order's total price so far.
    Private m_OrderTotal As Double

    ' documentLocator is the first method called when the SAX reader
    ' opens the XML document. Because this is the first event, it is
    ' a good place to initialize the class.
    ' 
    ' The parameter Value provides access to the XML document.
    Overridable WriteOnly Property CatchDocumentLocator() As IVBSAXLocator _
    Implements IVBSAXContentHandler.documentLocator
        Set(ByVal Value As IVBSAXLocator)

        End Set
    End Property

    ' startDocument is called when the SAX reader 
    ' starts reading the document.
    Overridable Sub CatchStartDocument() _
    Implements IVBSAXContentHandler.startDocument

    End Sub

    ' endDocument is called when the SAX reader is done reading 
    ' the document, either because it has reached the end of the 
    ' document or because it had a fatal error.
    Overridable Sub CatchEndDocument() _
    Implements IVBSAXContentHandler.endDocument

    End Sub

    ' startElement is called when the SAX reader 
    ' reads start of an element.
    Overridable Sub CatchStartElement( _
        ByRef strNamespaceURI As String, _
        ByRef strLocalName As String, _
        ByRef strQName As String, _
        ByVal oAttributes As MSXML2.IVBSAXAttributes) _
    Implements IVBSAXContentHandler.startElement
        ' See what kind of element this is.
        If strLocalName = "Order" Then
            ' Order.
            ' Start a new total.
            m_OrderTotal = 0
        ElseIf strLocalName = "Item" Then
            ' Item element. 
            ' Add to the current total.
            m_OrderTotal = m_OrderTotal + _
                CDbl(oAttributes.getValueFromName("", "UnitPrice")) * _
                CDbl(oAttributes.getValueFromName("", "Quantity"))
        End If
    End Sub

    ' endElement is called when the SAX reader 
    ' reads an element's closing tag.
    Overridable Sub CatchEndElement( _
        ByRef strNamespaceURI As String, _
        ByRef strLocalName As String, _
        ByRef strQName As String) _
    Implements IVBSAXContentHandler.endElement
        ' See if this is the end of an Order element.
        If strLocalName = "Order" Then
            ' This is the end of an Order element.
            ' Send out the accumulated total for the Order.
            RaiseEvent OrderTotaled(m_OrderTotal)
        End If
    End Sub

    ' The characters method is passed the characters that appear
    ' between an element's start and end tags.
    Overridable Sub CatchCharacters(ByRef strChars As String) _
    Implements IVBSAXContentHandler.characters

    End Sub

    ' startPrefixMapping is called when a URI namespace prefix 
    ' mapping starts. Occurs after the startElement call for the 
    ' element that contains it but the order of the startPrefixMapping
    ' and corresponding endPrefixMapping is not guaranteed.
    Overridable Sub CatchStartPrefixMapping( _
        ByRef strPrefix As String, _
        ByRef strURI As String) _
    Implements IVBSAXContentHandler.startPrefixMapping

    End Sub

    ' endPrefixMapping is called when a URI namespace prefix 
    ' mapping is ending. Occurs after the endElement call for the 
    ' element that contains it but the order of the startPrefixMapping
    ' and corresponding endPrefixMapping is not guaranteed.
    Overridable Sub CatchEndPrefixMapping( _
        ByRef strPrefix As String) _
    Implements IVBSAXContentHandler.endPrefixMapping

    End Sub

    ' ignorableWhitespace is not called by SAX2 because SAX2 is
    ' non-validating .
    Overridable Sub CatchIgnorableWhitespace( _
        ByRef strChars As String) _
    Implements IVBSAXContentHandler.ignorableWhitespace

    End Sub

    ' processingInstruction is called when teh SAX reader reads
    ' a processing instruction.
    Overridable Sub CatchProcessingInstruction( _
        ByRef strTarget As String, _
        ByRef strData As String) _
    Implements IVBSAXContentHandler.processingInstruction

    End Sub

    ' skippedEntity is called when the SAX reader skips an external
    ' DTD declaration and when it skips an entity. It skips an entity
    ' when it did not read that entity's declaration, for example
    ' if the entitiy was defined in an external declaration.
    Overridable Sub CatchSkippedEntity( _
        ByRef strName As String) _
    Implements IVBSAXContentHandler.skippedEntity

    End Sub
End Class
